"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClozeNoteSimple = void 0;
const ClozeNote_1 = require("./ClozeNote");
const ClozeTypeEnum_1 = require("./ClozeTypeEnum");
const utils_1 = require("./utils");
class ClozeNoteSimple extends ClozeNote_1.ClozeNote {
    constructor(raw, patterns) {
        super(raw, patterns);
    }
    get clozeType() {
        return ClozeTypeEnum_1.ClozeTypeEnum.SIMPLE;
    }
    initParsing(rawNote, patterns) {
        let clozeDeletions = [];
        let numCards = 0;
        patterns.forEach((pattern) => {
            const regex = pattern.getClozeRegex(ClozeTypeEnum_1.ClozeTypeEnum.SIMPLE);
            let match;
            while (match = regex.exec(rawNote)) {
                numCards++;
                let newCloze = {
                    raw: match.raw,
                    answer: match.answer,
                    seq: numCards,
                    hint: match.hint
                };
                clozeDeletions.push(newCloze);
            }
        });
        return { clozeDeletions, numCards };
    }
    getCardFront(cardIndex, format) {
        if (cardIndex >= this._numCards || cardIndex < 0) {
            throw new Error(`Card ${cardIndex} does not exist`);
        }
        if (!format) {
            format = new utils_1.simpleFormat();
        }
        let frontText = this.raw;
        for (const deletion of this._clozeDeletions) {
            if (deletion.seq !== cardIndex + 1) {
                frontText = frontText.replace(deletion.raw, deletion.answer); // Just show
                continue;
            }
            frontText = frontText.replace(deletion.raw, format.asking(deletion.answer, deletion.hint)); // Hide asked cloze
        }
        return frontText;
    }
    getCardBack(cardIndex, format) {
        if (cardIndex >= this._numCards || cardIndex < 0) {
            throw new Error(`Card ${cardIndex} does not exist`);
        }
        if (!format) {
            format = new utils_1.simpleFormat();
        }
        let backText = this.raw;
        for (const deletion of this._clozeDeletions) {
            if (deletion.seq === cardIndex + 1) {
                backText = backText.replace(deletion.raw, format.showingAnswer(deletion.answer, deletion.hint)); // Show as answer
            }
            else {
                backText = backText.replace(deletion.raw, deletion.answer); // Just show
            }
        }
        return backText;
    }
}
exports.ClozeNoteSimple = ClozeNoteSimple;
